PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - s -

- Segments : UserAgent
- segments : dsn::Net, dsn::Track
- SegmentTo : UserAgent
- Selection : UserAgent
- sets : UIActions
- SetTrack : UserAgent
- shapes : dsn::Padstack
- side : dsn::Layer
- SidePaneWidth : UserSettings
- SImage : UserAgent
- SKY : Color
- sOpposites : GridDirection
- src_pin : dsn::Connection
- sStrings : GridDirection
- Start : PCBoardMesh::IndexRange
- start_x : dsn::Track
- start_y : dsn::Track
- start_z : dsn::Track
- structure : dsn::Data
- Success : Action::Result, ResultRecord
- Sum : NavKeepoutCounts
- sVec : GridDirection